import { ScrollView, View } from "@tarojs/components";
import { ConfigProvider, Empty, Flex, Navbar } from "@taroify/core";
import './applyRecord.less'
import Taro, { useDidShow, useLoad } from "@tarojs/taro";
import { useState } from "react";
import services from "@/services";

const applyRecord = () => {

    const [statusBarHeight, setStatusBarHeight] = useState(0);

    const onBack = () => {
        Taro.navigateBack();
    };
    useLoad(() => {
        const systemInfo = Taro.getSystemInfoSync();
        setStatusBarHeight(systemInfo?.statusBarHeight ?? 0);
    });

    const [paginationInfo, setPaginationInfo] = useState<API.Pagination>();
    const [dataSource, setDataSource] = useState<any[]>([]);


    /** 无限加载 */
    const onScrollToLower = () => {
        if (paginationInfo?.hasNext) {
            getList(paginationInfo?.page + 1);
        } else {
            Taro.showToast({ title: '没有更多了', mask: true, icon: 'none' })
        }
    };
    const getList = async (page: number) => {
        services.report.getApplyRecord({ page, count: 20 }).then((res) => {
            setPaginationInfo(res.data);
            if (page === 1) {
                setDataSource(res.data.items);
            } else {
                setDataSource((prev) => [...prev, ...res.data.items]);
            }
        })
    }

    const [statiscData, setStatiscData] = useState<any>({})
    const getStatisc = async () => {
        const res = await services.report.applyRecordStatisc()
        if (res.code === 200) {
            setStatiscData(res.data)
        }
    }
    useDidShow(() => {
        getList(1);
        getStatisc()
    })

    return <View className="report_container4">
        <View className="decoration" />
        <View style={{ height: statusBarHeight }} />
        <ConfigProvider
            theme={{
                "—navbar-background-color": "transparent",
            }}
        >
            <Navbar safeArea="top">
                <Navbar.NavLeft onClick={onBack}>返回</Navbar.NavLeft>
            </Navbar>
        </ConfigProvider>
        <View className="titleBox">
            <View className="title">申请记录</View>
            <View className="statisc">
                共申请：{statiscData.total}项
            </View>
            <View className="statisc">
                已办结：{statiscData.completed}项
            </View>
        </View>
        <ScrollView
            scrollY
            onScrollToLower={onScrollToLower}
            style={{ height: `calc(100vh - ${statusBarHeight}px - 94px)` }}
        >
            <View className="contentView">
                {dataSource.length === 0 && (
                    <Empty style={{ marginTop: 100 }}>
                        <Empty.Description>暂无记录</Empty.Description>
                    </Empty>
                )}
                {dataSource.map((item) => {
                    const { id, name, createAt, elementName, nodeRemake } = item
                    return <View
                        key={id}
                        className="reportItemCard"
                    >
                        <Flex className="cell">
                            <Flex.Item span={6}>申请编号:</Flex.Item>
                            <Flex.Item span={16}>{id}</Flex.Item>
                        </Flex>
                        <Flex className="cell">
                            <Flex.Item span={6}>申请事项:</Flex.Item>
                            <Flex.Item span={16}>{name}</Flex.Item>
                        </Flex>
                        <Flex className="cell">
                            <Flex.Item span={6}>申请日期:</Flex.Item>
                            <Flex.Item span={16}>{createAt}</Flex.Item>
                        </Flex>
                        <Flex className="cell">
                            <Flex.Item span={6}>办理阶段:</Flex.Item>
                            <Flex.Item span={16}>{elementName}</Flex.Item>
                        </Flex>
                        <Flex className="cell">
                            <Flex.Item span={6}>办理说明:</Flex.Item>
                            <Flex.Item span={16}>{nodeRemake || '无'}</Flex.Item>
                        </Flex>
                    </View>
                })}
            </View>
        </ScrollView>
    </View>
}

export default applyRecord