import { ScrollView, View, Image } from "@tarojs/components";
import { ConfigProvider, Empty, Flex, Navbar } from "@taroify/core";
import icon22 from "@/assets/icon/icon22.png";
import './SuggestAndConsult.less'
import Taro, { useDidShow, useLoad } from "@tarojs/taro";
import { useState } from "react";
import { objectToQuery } from "@/utils";
import services from "@/services";

const SuggestAndConsult = () => {
    const [statusBarHeight, setStatusBarHeight] = useState(0);

    const onBack = () => {
        Taro.navigateBack();
    };
    useLoad(() => {
        const systemInfo = Taro.getSystemInfoSync();
        setStatusBarHeight(systemInfo?.statusBarHeight ?? 0);
    });

    const [paginationInfo, setPaginationInfo] = useState<API.Pagination>();
    const [dataSource, setDataSource] = useState<API.ReportRecordDto[]>([]);


    /** 无限加载 */
    const onScrollToLower = () => {
        if (paginationInfo?.hasNext) {
            getList(paginationInfo?.page + 1);
        } else {
            Taro.showToast({ title: '没有更多了', mask: true, icon: 'none' })
        }
    };
    const { serviceType } = Taro.getCurrentInstance().router?.params!
    const getList = async (page: number) => {
        services.report.getConsultSuggest({ page, count: 10, serviceType }).then((res) => {
            setPaginationInfo(res.data);
            if (page === 1) {
                setDataSource(res.data.items);
            } else {
                setDataSource((prev) => [...prev, ...res.data.items]);
            }
        })
    }

    useDidShow(() => {
        getList(1);
    });
    const onViewDetail = (item: API.ReportRecordDto) => {
        Taro.navigateTo({
            url: `/pages/Feedback/RecordDetail/index?` + objectToQuery(item),
        })
    }

    return <View className="report_container2">
        <View className="decoration" />
        <View style={{ height: statusBarHeight }} />
        <ConfigProvider
            theme={{
                "—navbar-background-color": "transparent",
            }}
        >
            <Navbar safeArea="top">
                <Navbar.NavLeft onClick={onBack}>返回</Navbar.NavLeft>
            </Navbar>
        </ConfigProvider>
        <View className="title">其他市民{serviceType === '1' ? '建议' : '咨询'}</View>
        <ScrollView
            scrollY
            onScrollToLower={onScrollToLower}
            style={{ height: `calc(100vh - ${statusBarHeight}px - 94px)` }}
        >
            <View className="contentView">
                {dataSource.length === 0 && (
                    <Empty style={{ marginTop: 100 }}>
                        <Empty.Description>暂无记录</Empty.Description>
                    </Empty>
                )}
                {dataSource.map((item) => {
                    return (
                        <View
                            key={item.id}
                            className="reportItemCard"
                            onTap={() => {
                                onViewDetail(item);
                            }}
                        >
                            <Flex>
                                <Flex.Item span={3}>
                                    <Image src={icon22} className="robotIcon"></Image>
                                </Flex.Item>
                                <Flex.Item span={21}>
                                    <View className="reportTitle">{item.content}</View>
                                    <View className="reportTime">{item.createTime}</View>
                                    {item.handlingStatus !== "1" ? (
                                        <View className="reportAnswer-card">
                                            <View className="reportAnswer-title">
                                                {item.handlingDeptName} 回复
                                            </View>
                                            <View className="reportAnswer-content">
                                                {item.handleReply}
                                            </View>
                                        </View>
                                    ) : (
                                        <View className="noRecover">待回复...</View>
                                    )}
                                </Flex.Item>
                            </Flex>
                        </View>
                    );
                })}
            </View>
        </ScrollView>
    </View>
}

export default SuggestAndConsult