import { ScrollView, View } from "@tarojs/components";
import { ConfigProvider, Empty, Flex, Navbar } from "@taroify/core";
import './usageRecord.less'
import Taro, { useDidShow, useLoad } from "@tarojs/taro";
import { useState } from "react";
import services from "@/services";

const usageRecord = () => {

    const [statusBarHeight, setStatusBarHeight] = useState(0);

    const onBack = () => {
        Taro.navigateBack();
    };
    useLoad(() => {
        const systemInfo = Taro.getSystemInfoSync();
        setStatusBarHeight(systemInfo?.statusBarHeight ?? 0);
    });

    const [paginationInfo, setPaginationInfo] = useState<API.Pagination>();
    const [dataSource, setDataSource] = useState<any[]>([]);


    /** 无限加载 */
    const onScrollToLower = () => {
        if (paginationInfo?.hasNext) {
            getList(paginationInfo?.page + 1);
        } else {
            Taro.showToast({ title: '没有更多了', mask: true, icon: 'none' })
        }
    };
    const getList = async (page: number) => {
        services.report.getUsageRecord({ page, count: 20, type: '' }).then((res) => {
            setPaginationInfo(res.data);
            if (page === 1) {
                setDataSource(res.data.items);
            } else {
                setDataSource((prev) => [...prev, ...res.data.items]);
            }
        })
    }

    useDidShow(() => {
        getList(1);
    })

    return <View className="report_container3">
        <View className="decoration" />
        <View style={{ height: statusBarHeight }} />
        <ConfigProvider
            theme={{
                "—navbar-background-color": "transparent",
            }}
        >
            <Navbar safeArea="top">
                <Navbar.NavLeft onClick={onBack}>返回</Navbar.NavLeft>
            </Navbar>
        </ConfigProvider>
        <View className="title">便民服务使用记录</View>
        <ScrollView
            scrollY
            onScrollToLower={onScrollToLower}
            style={{ height: `calc(100vh - ${statusBarHeight}px - 94px)` }}
        >
            <View className="contentView">
                {dataSource.length === 0 && (
                    <Empty style={{ marginTop: 100 }}>
                        <Empty.Description>暂无记录</Empty.Description>
                    </Empty>
                )}
                {dataSource.map((item) => {
                    return <View
                        key={item.id}
                        className="reportItemCard"
                    >
                        <Flex>
                            <Flex.Item span={8}>
                                {item.serviceName}
                            </Flex.Item>
                            <Flex.Item span={16}>
                                {item.createTime}
                            </Flex.Item>
                        </Flex>
                    </View>
                })}
            </View>
        </ScrollView>
    </View>
}

export default usageRecord