import { getUserInfo2, saveUserInfo } from "@/services/loginController"
import useGlobalStore from "@/store";
import { View, Text, Button, Input, RadioGroup, Radio } from "@tarojs/components";
import Taro, { useLoad } from "@tarojs/taro";
import './userInfo.less'
import { useState } from "react";

const UserInfo = () => {
    const { userInfo } = useGlobalStore();

    const [info, setInfo] = useState<any>({})
    const getInfo = async () => {
        const res = await getUserInfo2()
        if (res.code === 200) {
            console.log(res);
            setInfo(res.data || {
                userGender: "0",
                userArea: '新都区'
            })
        }
    }

    useLoad(() => {
        getInfo()
    })

    const saveData = async () => {
        Taro.showModal({
            title: '提示',
            content: '确定要保存当前用户信息吗？',
            success: async (res) => {
                if (res.confirm) {
                    const res = await saveUserInfo(info)
                    if (res.code === 200) {
                        Taro.showToast({ title: '保存成功', icon: 'none' })
                    }
                }
            }
        })
    }

    return <View className="box">
        <View className="item">
            <Text className="left">用户名</Text>
            <Text className="right">{userInfo?.nickname}</Text>
        </View>
        <View className="item">
            <Text className="left">手机号</Text>
            <Text className="right">{userInfo?.mobile}</Text>
        </View>
        <View className="item">
            <Text className="left">性别</Text>
            <RadioGroup onChange={(e) => {
                const userGender = e.detail.value
                setInfo({ ...info, userGender })
            }}>
                <Radio className="radio" checked={info.userGender === '0'} value="0">男</Radio>
                <Radio className="radio" checked={info.userGender === '1'} value="1">女</Radio>
            </RadioGroup>
        </View>
        <View className="item">
            <Text className="left">所在区域</Text>
            <Input className="inp" value={info.userArea} onInput={(e) => {
                const userArea = e.detail.value
                setInfo({ ...info, userArea })
            }} />
        </View>
        <Button className="btn" onClick={saveData}>保存</Button>
    </View>
}

export default UserInfo 