import { getConsultList, getMapMakersByType, getPolicyList } from '@/services/commonController'
import './smartRecommend.less'
import { Search, Space, Tabs, Tag } from '@taroify/core'
import { ScrollView, Image, View, Text } from '@tarojs/components'
import { useMemo, useState } from 'react'
import Taro, { useLoad } from '@tarojs/taro'

const SmartRecommend = () => {
    const [searchText, setSearchText] = useState('')

    // 常见咨询
    const [commonInquiryList, setCommonInquiryList] = useState<any[]>([])
    const getCommonInquiry = async (searchText: string) => {
        const res = await getConsultList(searchText)
        if (res.code === 200) {
            setCommonInquiryList(res.data)
        }
    }

    // 政策法规
    const [lawsRegulationsList, setLawsRegulationsList] = useState<any[]>([])
    const getLawsRegulations = async (searchText: string) => {
        const res = await getPolicyList(searchText)
        if (res.code === 200) {
            setLawsRegulationsList(res.data)
        }
    }

    // 地图点位
    const [officeList, setOfficeList] = useState<any[]>([])
    const getOffice = async (searchText: string) => {
        const res = await getMapMakersByType({ searchText })
        if (res.code === 200) {
            console.log(res);
            setOfficeList(res.data)
        }
    }

    const allSearch = (searchText: string = '') => {
        getCommonInquiry(searchText)
        getLawsRegulations(searchText)
        getOffice(searchText)
    }

    useLoad(() => {
        allSearch(searchText)
    })

    const antistop = useMemo<string[]>(() => {
        return ['交通罚款', '医保报销','火车票','快递服务']
    }, [])

    return <View className='pageBox'>
        <Search
            value={searchText}
            placeholder="请输入搜索关键词"
            onChange={(e) => setSearchText(e.detail.value)}
            action={<View onClick={() => allSearch(searchText)}>搜索</View>}
        />
        <View className='antistopBox'>
            {antistop.map((v, i) => {
                return <View className='antistopTxt' key={i} onClick={() => {
                    setSearchText(v)
                    allSearch(v)
                }}>{v}</View>
            })}
        </View>
        <Tabs>
            <Tabs.TabPane title="常见咨询">
                <ScrollView className='scrollBox' scrollY>
                    {commonInquiryList.map((item) => {
                        return <ListItem key={item.id} data={item} />;
                    })}
                </ScrollView>
            </Tabs.TabPane>
            <Tabs.TabPane title="办事地点">
                <ScrollView className='scrollBox' scrollY>
                    {officeList.map((item) => {
                        return <ListItem3 key={item.id} data={item} />;
                    })}
                </ScrollView>
            </Tabs.TabPane>
            <Tabs.TabPane title="政策法规">
                <ScrollView className='scrollBox' scrollY>
                    {lawsRegulationsList.map((item) => {
                        return <ListItem2 key={item.id} data={item} />;
                    })}
                </ScrollView>
            </Tabs.TabPane>
        </Tabs>
    </View>
}

export default SmartRecommend

const ListItem = ({ data }: { data: API.LawDto }) => (
    <View
        className="list-item"
        onTap={() => {
            Taro.navigateTo({
                url: "/pages/Article/index" + "?desc=" + data.description,
            });
        }}
    >
        <View>
            <View className="list-title">{data.title}</View>
            <Text className="list-content">{data.digestText}</Text>
            <View className="time">{data.createTime}</View>
        </View>
        <View>
            <Image
                src={data.coverImage}
                mode="aspectFill"
                className="list-img"
            />
        </View>
    </View>
)

const ListItem2 = ({ data }: { data: API.LawDto }) => (
    <View
        className="list-item2"
        onTap={() => {
            Taro.navigateTo({
                url: "/pages/Article/index" + "?desc=" + data.description,
            });
        }}
    >
        <View>
            <Image
                src={data.coverImage}
                mode="aspectFill"
                className="list-img"
            ></Image>
        </View>
        <View>
            <View className="list-title">{data.title}</View>
            <Text className="list-content">{data.digestText}</Text>
            <View className="time">{data.createTime}</View>
        </View>
    </View>
);

const ListItem3 = ({ data }: { data: API.PointInfoDto }) => {
    return (
        <View className="list-item3">
            <Space align="center">
                <View className="list-title">{data.locationTitle}</View>
                <Tag
                    style={{
                        backgroundColor: "rgba(227, 235, 255, 1)",
                        color: "rgba(46, 108, 255, 1)",
                    }}
                >
                    {data.workTypeText}
                </Tag>
            </Space>
            <View>{data.address ?? "暂无地址"}</View>
            <View>工作时间：{data.workTime}</View>
        </View>
    );
};
