import api from "./core/api";
import request from "./core/request";

/** 提交上报的信息 */
export function submitUserReport(params: {
  /** 1投诉、2建议、3咨询、4举报 */
  type: 1 | 2 | 3 | 4;
  content: string;
  annex1?: string;
  annex2?: string;
  annex3?: string;
  anonymousFlag: 1 | 0;
}) {
  return request<Resp<any>>(
    api.reportUrl + "/citizenServices/saveCitizenInfo",
    {
      method: "POST",
      data: params,
    }
  );
}
/** 获取用户上报记录 */
export function getReportList(params: {
  /** 1投诉、2建议、3咨询、4举报 */
  type: 1 | 2 | 3 | 4;
  page: number;
  count: number;
}) {
  return request<Resp<API.Pagination<API.ReportRecordDto>>>(
    api.reportUrl + "/citizenServices/getCitizenServicesInfoList",
    {
      method: "POST",
      params: params,
    }
  );
}
/** @description 获取个人中心统计信息 */
export function getPersonalCenterStatistics() {
  return request<Resp<API.PersonalCenterStatisticsDto[]>>(
    api.reportUrl + "/citizenServices/personalCenterStatistics",
    {
      method: "POST",
    }
  );
}

/**
 *  @description 获取其他咨询与建议
 */
export function getConsultSuggest(params:any) {
    return request<Resp<API.Pagination<API.ReportRecordDto>>>(
        api.reportUrl + "/citizenServices/getCitizenIntegralList/otherCitizen",
        {
            method: "POST",
            params
        }
    );
}

/**
 *  @description 获取其他咨询与建议
 */
export function getUsageRecord(params:any) {
    return request<Resp<API.Pagination<API.ReportRecordDto>>>(
        api.reportUrl + "/citizenServices/getCitizenServicesRecordList",
        {
            method: "POST",
            params
        }
    );
}

/**
 *  @description 获取通知消息
 */
export function userInform() {
    return request<Resp<any>>(
        api.reportUrl + "/citizenServices/getMyMessageList",
        { method: "POST" }
    );
}

/**
 *  @description 获取通知消息详情（已读）
 */
export function userInformRead(serviceId:string) {
    return request<Resp<any>>(
        api.reportUrl + "/citizenServices/getMyMessageDetail?serviceId=" + serviceId,
        { method: "POST" }
    );
}

/**
 *  @description 一键已读
 */
export function oneKeyRead() {
    return request<Resp<any>>(
        api.reportUrl + "/citizenServices/getMyMessageDetail" ,
        { method: "POST" }
    );
}

/**
 * @description 增加使用记录  
 */
export function addUseRecord(serviceType: '1' | '2' | '3' | '4') {
    return request<Resp<any>>(api.reportUrl + "/convenienceService/addUseRecord?serviceType=" + serviceType, {
        method: "POST",
        header: {
            "content-type": "application/x-www-form-urlencoded",
        },
    });
}

/**
 * @description 获取申请记录 
 */
export function getApplyRecord(params:any) {
    return request<Resp<API.Pagination<API.ReportRecordDto>>>(
        "/hncy/record/list",
        {
            method: "POST",
            params
        }
    );
}

/**
 * @description 申请记录详情
 */
export function applyRecordDetail(id:string) {
    return request<Resp<any>>(
        "/hncy/record/getDetails?id=" + id,
        {
            method: "POST"
        }
    );
}

/**
 * @description 申请记录统计
 */

export function applyRecordStatisc() {
    return request<Resp<any>>(
        "/hncy/record/unreadEnd",
        {
            method: "GET"
        }
    );
}
